```{include} ../README.md
:start-line: 0
:end-line: 1
```

For most use cases, set up LaminDB through the CLI `lndb` as covered in the [LaminDB guide](https://lamin.ai/docs/db/guide).

These docs provide the reference for the API that underlies the CLI: `lndb_setup`.

```{toctree}
:maxdepth: 1

guide/index
api
notes/index
faq/index
changelog
```
